@@ -1,4 +1,4 @@
-/* $Id: xfsm-compat-kde.c 20833 2006-04-09 18:08:17Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- *                                                                              
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *                                                                              
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -48,6 +48,9 @@
 #include <xfce4-session/xfsm-compat-kde.h>
 
 
+static gboolean kde_compat_started = FALSE;
+
+
 static gboolean
 run_timeout (gpointer user_data)
 {
@@ -114,6 +117,9 @@ xfsm_compat_kde_startup (XfsmSplashScreen *splash)
 {
   gchar command[256];
 
+  if (G_UNLIKELY (kde_compat_started))
+    return;
+
   if (G_LIKELY (splash != NULL))
     xfsm_splash_screen_next (splash, _("Starting KDE services"));
 
@@ -132,15 +138,22 @@ xfsm_compat_kde_startup (XfsmSplashScreen *splash)
                                 "KDE_MULTIHEAD \"true\"");
       run (command);
     }
+
+  kde_compat_started = TRUE;
 }
 
 
 void
 xfsm_compat_kde_shutdown (void)
 {
+  if (G_UNLIKELY (!kde_compat_started))
+    return;
+
   /* shutdown KDE services */
   run ("kdeinit_shutdown");
   run ("dcopserver_shutdown");
   run ("artsshell -q terminate");
+
+  kde_compat_started = FALSE;
 }
 
