@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -48,6 +48,8 @@
 #include <xfce4-session/shutdown.h>
 #include <xfce4-session/xfsm-global.h>
 
+#include <libxfsm/xfsm-util.h>
+
 
 /* global variables */
 gboolean          verbose = FALSE;
